import $ from 'jquery';
import { tns } from 'tiny-slider/src/tiny-slider';

/**
 * ------------------------------------------------------------------------
 * Constantes
 * ------------------------------------------------------------------------
 */

const NAME               = 'slider';
const DATA_KEY           = `app.${NAME}`;
const EVENT_KEY          = `.${DATA_KEY}`;
const DATA_API_KEY       = '.data-api';

const Event = {
  LOAD_DATA_API : `load${EVENT_KEY}${DATA_API_KEY}`
};

const Default = {
  items: 1,
  gutter: 10,
  speed: 1000,
  prevButton: '.tns-control-prev',
  nextButton: '.tns-control-next',
  nav: false,
  autoplay: true,
  autoplayHoverPause: true,
  autoplayButtonOutput: false
};

const Selector = {
  ITEMS: '.tns-slider-items',
  PREVIOUS: '.tns-control-prev',
  NEXT: '.tns-control-next',
  DATA_SLIDER: '[data-slider]'
};

/**
 * ------------------------------------------------------------------------
 * Fonctions
 * ------------------------------------------------------------------------
 */

// Initialise un élément en carrousel avec tiny-slider.
function Slider(element) {
  const items = element.querySelector(Selector.ITEMS);
  if (!items) {
    return null;
  }

  const options = Object.assign({}, Default, {
    container: items
  });

  // cherche les boutons de navigation
  const prevButton = element.querySelector(Selector.PREVIOUS);
  const nextButton = element.querySelector(Selector.NEXT);

  if (prevButton) {
    options.prevButton = prevButton;
  }
  if (nextButton) {
    options.nextButton = nextButton;
  }

  // tente de charger des options supplémentaires
  const data = element.getAttribute('data-slider');
  if (data) {
    try {
      Object.assign(options, JSON.parse(data));
    } catch (e) {
      // eslint-disable-next-line no-console
      console.error('Impossible de charger les options', element, e);
    }
  }

  return tns(options);
}

/**
 * ------------------------------------------------------------------------
 * Data Api implementation
 * ------------------------------------------------------------------------
 */

$(window).on(Event.LOAD_DATA_API, () => {
  const sliders = [].slice.call(document.querySelectorAll(Selector.DATA_SLIDER));
  for (let i = 0, len = sliders.length; i < len; i++) {
    Slider(sliders[i]);
  }
});

export default Slider;
