import functools

from django import template
from django.conf import settings
from django.contrib.staticfiles import finders
from django.templatetags.static import static

register = template.Library()


@functools.lru_cache(maxsize=None)
def get_minified_static_path(path):
    """Retourne si possible le chemin compressé d'un fichier statique.

    Détermine et retourne le chemin relatif à utiliser pour le fichier
    statique `path`, en fonction de l'environnement. Si elle existe, la
    version compressée (e.g. avec le suffixe `.min` avant l'extension) du
    fichier sera retournée quand le débogage est désactivé.
    """
    if settings.DEBUG:
        return path
    base, ext = path.rsplit('.', 1)
    min_path = '{}.min.{}'.format(base, ext)
    if finders.find(min_path):
        return min_path
    return path


@register.simple_tag
def min_static(path):
    """Retourne le chemin absolu d'un fichier statique compressé."""
    return static(get_minified_static_path(path))


@register.simple_tag(takes_context=True)
def homepage_url(context):
    """Retourne l'URL relative vers la page d'accueil."""
    try:
        return context['request'].META['SCRIPT_NAME'] or '/'
    except KeyError:
        return '/'
