from django.template import Context, RequestContext, Template
from django.test.client import Client

import pytest

from ..middleware import OrganizationInfoMiddleware
from ..models import OrganizationInfo


@pytest.mark.django_db
class TemplateTestMixin:
    @pytest.fixture(autouse=True)
    def setup_site(self, default_site):
        self.site = default_site

    def get_request(self):
        request = Client().get('/test/', HTTP_HOST=self.site.hostname)
        request.site = self.site
        return request

    def render(self, string, context=None, request=None):
        if request is None:
            request = self.get_request()
        template = Template(string)
        context = RequestContext(request, context)
        return template.render(context)


class TestContextProcessor(TemplateTestMixin):
    def test_org_info_middleware(self):
        middleware = OrganizationInfoMiddleware(lambda r: r)

        org_info = middleware(self.get_request()).org_info
        assert isinstance(org_info, OrganizationInfo)
        assert org_info.site == self.site

        request = self.get_request()
        request.site = None
        assert middleware(request).org_info is None

    def test_org_info(self):
        assert self.render('{{ org_info.phone }}') == ''

        request = self.get_request()
        request.org_info = OrganizationInfo.objects.create(
            phone="0123456789", site=self.site
        )
        assert (
            self.render('{{ org_info.phone }}', request=request)
            == "0123456789"
        )

    def test_no_context_processor(self):
        template = Template('{{ org_info.phone }}')
        assert template.render(Context()) == ''
