from django.urls import reverse_lazy

import pytest

from lens.utils.tests import count_text_in_content

from ..models import OrganizationInfo


@pytest.mark.django_db
class TestPrivacyPolicy:
    url = reverse_lazy('privacy-policy')

    @pytest.fixture(autouse=True)
    def setup(self, default_site):
        self.org_info = OrganizationInfo.for_site(default_site)

    def test_not_found(self, client):
        response = client.get(self.url)
        assert response.status_code == 404

    def test_with_policy(self, client):
        self.org_info.privacy_policy = "Notre politique"
        self.org_info.save()

        response = client.get(self.url)
        assert response.status_code == 200
        assert count_text_in_content(response, "Notre politique")

    def test_with_tracking_code(self, client):
        self.org_info.tracking_code = "alert('tracking');"
        self.org_info.save()

        response = client.get(self.url)
        assert response.status_code == 200
        assert count_text_in_content(response, "alert('tracking');")
        assert count_text_in_content(response, "Suivi de votre visite")

    def test_with_both(self, client):
        self.org_info.privacy_policy = "Notre politique"
        self.org_info.tracking_code = "alert('tracking');"
        self.org_info.save()

        response = client.get(self.url)
        assert response.status_code == 200
        assert count_text_in_content(response, "Notre politique")
        assert count_text_in_content(response, "alert('tracking');")
        assert not count_text_in_content(response, "Suivi de votre visite")
