from django.http import Http404
from django.views.generic import TemplateView

from wagtail.search.models import Query

from lens.blog.models import BlogArticlePage

from .models import StandardPage


class PrivacyPolicyView(TemplateView):
    """
    Affiche la politique de confidentialité des données.
    """

    template_name = 'base/privacy_policy.html'

    def get(self, request, *args, **kwargs):
        if not request.org_info.has_privacy_policy:
            raise Http404("La politique de confidentialité n'est pas définie.")
        return super().get(request, *args, **kwargs)


class SearchView(TemplateView):
    """
    Recherche des mots clés dans les pages et articles.
    """

    template_name = 'base/search_results.html'

    def get(self, request, *args, **kwargs):
        self.query = self.request.GET.get('query', None)
        return super().get(request, *args, **kwargs)

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        if self.query:
            context['standard_page_results'] = (
                StandardPage.objects.live().public().search(self.query)
            )
            context['articles_results'] = (
                BlogArticlePage.objects.live().public().search(self.query)
            )
            # ajoute un score pour de potentiels résultats favorisés
            Query.get(self.query).add_hit()
        context['search_query'] = self.query
        return context
