from django.utils.functional import cached_property

from wagtail.core import blocks

from lens.utils.blocks import HideableStructBlock


class LastArticlesBlock(HideableStructBlock):
    """
    Bloc présentant les derniers articles contenus dans une rubrique.
    """

    parent_page = blocks.PageChooserBlock(
        target_model='blog.BlogCategoryPage',
        label="Rubrique",
        help_text="La page racine contenant les articles à afficher.",
    )
    limit = blocks.IntegerBlock(
        default=6, min_value=1, max_value=50, label="Nombre d'articles"
    )
    add_page_link = blocks.BooleanBlock(
        default=True,
        required=False,
        label="Lien vers la rubrique",
        help_text=(
            "S'il faut ajouter en dessous des articles un lien vers la "
            "rubrique, afin de voir tous les articles."
        ),
    )

    class Meta:
        label = "Derniers articles"
        icon = 'doc-full'
        template = 'blog/blocks/last_articles_block.html'
        closed = True

    @cached_property
    def definition(self):
        definition = super().definition
        # personnalise le titre du bloc
        definition['titleTemplate'] = "${limit} derniers articles"
        return definition

    def get_context(self, value, **kwargs):
        context = super().get_context(value, **kwargs)
        context['articles'] = value['parent_page'].articles[: value['limit']]
        return context
