# Generated by Django 2.2.24 on 2021-11-02 10:03

import json
from django.db import migrations
from django.core.serializers.json import DjangoJSONEncoder


# These blocks contain (or can contain) one or more ParagraphBlock
# That do not need to be hideable independently from its parent.
# Therefore there is no need to migrate them
NOT_MIGRATED_BLOCKS = [
    "quote_block",
    "icon_text_block",
    "image_text_block",
    "card_block",
    "media_object_block",
]

def richtextblock_to_structblock(block):
    return {
        'type': 'paragraph_structblock',
        'value': {
            'text': block['value'],
            'hidden': False,
        }
    }

def structblock_to_richtextblock(block):
    return {
        'type': 'paragraph_block',
        'value': block['value']['text']
    }

def migrated(data):
    if isinstance(data, list):
        return [migrated(item) for item in data]
    if isinstance(data, dict):
        if data.get('type', None) == "paragraph_block":
            data = richtextblock_to_structblock(data)
        elif data.get('value', None) and isinstance(data['value'], dict) and data['type'] not in NOT_MIGRATED_BLOCKS:
            data['value'] = {k:migrated(d) for k, d in data['value'].items()}
        return data
    return data

def unmigrated(data):
    if isinstance(data, list):
        return [unmigrated(item) for item in data]
    if isinstance(data, dict):
        if data.get('type', None) == "paragraph_structblock":
            data = structblock_to_richtextblock(data)
        elif data.get('value', None) and isinstance(data['value'], dict) and data['type'] not in NOT_MIGRATED_BLOCKS:
            data['value'] = {k:unmigrated(d) for k, d in data['value'].items()}
        return data
    return data

def migrate(apps, mapper):
    BlogArticlePage = apps.get_model('blog', 'BlogArticlePage')

    blog_article_pages = BlogArticlePage.objects.all()

    for page in blog_article_pages:
        data = list(page.body.raw_data)
        page.body = json.dumps(mapper(data), cls=DjangoJSONEncoder)
        page.save()

        for revision in page.revisions.all():
            revision_content = json.loads(revision.content_json)
            if 'body' in revision_content:
                data = json.loads(revision_content['body'])
                revision_content['body'] = json.dumps(
                    mapper(data), cls=DjangoJSONEncoder
                )
                revision.content_json = json.dumps(
                    revision_content, cls=DjangoJSONEncoder
                )
                revision.save()

def forwards(apps, schema_editor):
    migrate(apps, migrated)

def backwards(apps, schema_editor):
    migrate(apps, unmigrated)


class Migration(migrations.Migration):

    dependencies = [
        ('blog', '0010_add_paragraph_structblock_to_basestreamblock'),
    ]

    operations = [
        migrations.RunPython(forwards, backwards),
    ]
