import datetime

from django.core.management import call_command

import pytest
from wagtail.core.models import Page
from wagtail.images.tests.utils import Image, get_test_image_file_jpeg

from lens.blog.models import BlogArticlePage, BlogCategoryPage


@pytest.fixture(scope='class')
def with_blog_site(django_db_setup, django_db_blocker, with_user_admin):
    with django_db_blocker.unblock():
        call_command('loaddata', 'blog_site.json')

        # crée une vraie image de test
        image = Image.objects.get(pk=1)
        image.file = get_test_image_file_jpeg(filename='bar.jpg')
        image.save()


@pytest.fixture
def articles_page():
    root_page = Page.objects.filter(pk=1).get()
    parent_page = BlogCategoryPage(title='blog_cat_page')
    root_page.add_child(instance=parent_page)
    parent_page.save()
    for n in range(1, 4):
        article = BlogArticlePage(title="Article {}".format(n))
        if n == 1:
            article.first_published_at = (
                datetime.date.today() - datetime.timedelta(days=1)
            )
        else:
            article.first_published_at = datetime.date.today()
        parent_page.add_child(instance=article)
        article.save()
    parent_page.save()
    return parent_page


@pytest.fixture
def no_article_page():
    root_page = Page.objects.filter(pk=1).get()
    parent_page = BlogCategoryPage(title='blog_cat_page')
    root_page.add_child(instance=parent_page)
    parent_page.save()
    return parent_page
