import pytest
from bs4 import BeautifulSoup

from lens.blog.blocks import LastArticlesBlock


class BlockTest:
    def render(self, data, block=None):
        if block is None:
            block = self.block
        return block.render(block.to_python(data))

    def render_html(self, *args, **kwargs):
        return BeautifulSoup(self.render(*args, **kwargs), 'html.parser')


@pytest.mark.django_db
class TestLastArticlesBlock(BlockTest):
    block = LastArticlesBlock()

    def test_render_for_given_articles_limit(self, articles_page):
        data = {'limit': 2, 'parent_page': articles_page}
        html = self.render(data)
        # La fixture est configurée pour que l'article 1 soit plus
        # ancien que les autres, il ne doit donc pas apparaître
        assert "Article 1" not in html
        assert "Article 2" in html
        assert "Article 3" in html

        # Le lien vers tous les articles devrait être présent par défaut
        assert "Tous les articles" in html

    def test_render_when_no_article(self, no_article_page):
        data = {'limit': 2, 'parent_page': no_article_page}
        assert (
            "Il n'y a aucun article à afficher pour le moment."
            in self.render(data)
        )

    def test_render_when_add_page_link_is_not_toggled(self, articles_page):
        data = {
            'limit': 2,
            'parent_page': articles_page,
            'add_page_link': False,
        }
        assert "Tous les articles" not in self.render(data)

    def test_render_when_hidden(self, articles_page):
        data = {
            'limit': 2,
            'parent_page': articles_page,
            'add_page_link': False,
            'hidden': True,
        }
        assert self.render(data) == ''
