from django.core.exceptions import ValidationError

import pytest
from wagtail.core.models import Site

from lens.base.models import StandardPage
from lens.blog.models import BlogCategoryPage, FeedSettings


@pytest.mark.django_db
@pytest.mark.usefixtures('with_blog_site')
class TestFeedSettings:
    def setup(self):
        self.site = Site.objects.get(is_default_site=True)
        self.settings = FeedSettings.for_site(self.site)

    def clean_categories(self):
        return FeedSettings.categories.field.stream_block.clean(
            self.settings.categories
        )

    def test_categories(self):
        category = BlogCategoryPage.objects.first()
        self.settings.categories = [('category', category)]
        assert self.clean_categories()

        self.settings.save()
        self.settings.refresh_from_db()
        assert self.settings.categories[0].value == category

    def test_categories_not_allowed(self):
        page = StandardPage.objects.first()
        self.settings.categories = [('category', page)]
        with pytest.raises(ValidationError):
            self.clean_categories()

    def test_str(self):
        self.settings.site.site_name = "Foo"
        assert str(self.settings) == "Foo"
        self.settings.site.site_name = None
        assert str(self.settings) == "Ville de Lens"
