import datetime

from django.core.management import call_command

import pytest

from lens.events.models import Event


@pytest.fixture(scope='class')
def with_user_admin(django_db_setup, django_db_blocker):
    with django_db_blocker.unblock():
        call_command('loaddata', 'user_admin.json')


@pytest.fixture
def oneday_event(django_db_blocker):
    with django_db_blocker.unblock():
        return Event.objects.create(
            title="Event test - One day",
            date_start=datetime.date.today() + datetime.timedelta(1),
            slug='event_test_1d',
        )


@pytest.fixture
def manydays_event(django_db_blocker):
    with django_db_blocker.unblock():
        return Event.objects.create(
            title="Event test - Many days",
            date_start=datetime.date.today() + datetime.timedelta(1),
            date_end=datetime.date.today() + datetime.timedelta(4),
            time_start=datetime.time(hour=8),
            time_end=datetime.time(hour=18, minute=30),
            slug='event_test_manyd',
        )


@pytest.fixture
def events():
    for n in range(1, 4):
        event = Event(
            title=f"Event {n}",
            date_start=datetime.date.today() + datetime.timedelta(days=n),
            slug=f'event{n}',
        )
        event.save()
    return
