from django.utils.html import format_html, mark_safe

from wagtail.contrib.modeladmin.options import ModelAdmin, modeladmin_register

from .models import Demarche


class DemarcheModelAdmin(ModelAdmin):
    model = Demarche
    menu_label = "Démarches"
    menu_icon = 'form'
    # Liste des objets
    list_display = ('icon_formatted', 'name_formatted', 'link')
    list_display_add_buttons = 'name_formatted'

    def get_extra_class_names_for_field_col(self, obj, field_name):
        if field_name == 'name_formatted':
            return ['title']
        return []

    # Mise en forme des champs
    # ------------------------

    def icon_formatted(self, obj):
        return format_html(
            '<div class="demarche-icon">{}</div>', mark_safe(obj.icon_inline)
        )

    icon_formatted.short_description = "Icône"

    def name_formatted(self, obj):
        return format_html('<h2>{}</h2>', obj.name)

    name_formatted.short_description = "Nom"
    name_formatted.admin_order_field = 'name'

    def link(self, obj):
        if obj.external_link:
            return format_html(
                '<a href="{}" title="Voir le lien">Lien externe</a>',
                obj.external_link,
            )
        return format_html(
            'Page : <a href="{}" title="Voir la page">{}</a>',
            obj.page_link.url,
            obj.page_link.title,
        )

    link.short_description = "Lien"


modeladmin_register(DemarcheModelAdmin)
