from django.utils.functional import cached_property

from wagtail.core import blocks

from lens.utils.blocks import HideableStructBlock


class UpcomingEventsBlock(HideableStructBlock):
    """
    Bloc présentant les évènements à venir.
    """

    limit = blocks.IntegerBlock(
        default=6, min_value=1, max_value=50, label="Nombre d'évènements"
    )
    add_all_link = blocks.BooleanBlock(
        default=True,
        required=False,
        label="Lien vers l'agenda",
        help_text=(
            "S'il faut ajouter en dessous du carrousel un lien vers l'agenda, "
            "afin de voir tous les évènements à venir."
        ),
    )

    class Meta:
        label = "Évènements à venir"
        icon = 'date'
        template = 'events/blocks/upcoming_events_block.html'
        closed = True

    @cached_property
    def definition(self):
        definition = super().definition
        # Personnalise le titre du bloc
        definition['titleTemplate'] = "${limit} prochains évènements"
        return definition

    def get_context(self, value, **kwargs):
        from .models import Event

        context = super().get_context(value, **kwargs)
        context['events'] = Event.objects.live().upcoming()[: value['limit']]
        return context
