import pytest

from lens.events.blocks import UpcomingEventsBlock
from lens.utils.tests import BlockTest


@pytest.mark.django_db
class TestUpcomingEventsBlock(BlockTest):
    block = UpcomingEventsBlock()

    def test_render_for_given_events_limit(self, events):
        data = {'limit': 2}
        html = self.render(data)
        assert "Event 1" in html
        assert "Event 2" in html
        # C'est "Event 3" qui ne devrait pas apparaître car sa date est la
        # plus éloignée dans le temps
        assert "Event 3" not in html

        # Un bouton vers la page qui regroupe tous les évènements devrait
        # être présent par défaut
        assert "Tous les évènements" in html

    def test_render_when_add_all_link_is_not_toggled(self, events):
        data = {'limit': 2, 'add_all_link': False}
        html = self.render(data)
        assert "Tous les évènements" not in html

    def test_render_when_no_event(self):
        data = {'limit': 2}
        html = self.render(data)
        assert "Il n'y a aucun évènement à venir pour le moment." in html

    def test_render_when_hidden(self, events):
        data = {'limit': 2, 'hidden': True}
        assert self.render(data) == ''
