from django.utils.html import format_html, format_html_join

from wagtail.contrib.modeladmin.options import (
    ModelAdmin,
    ModelAdminGroup,
    modeladmin_register,
)

from .models import Event, Place


class EventModelAdmin(ModelAdmin):
    model = Event
    menu_label = "Évènements"
    menu_icon = 'date'
    # Liste des objets
    list_display = (
        'title_formatted',
        'tags_list',
        'str_date',
        'str_time',
        'live',
    )
    list_filter = ('date_start', 'date_end')
    search_fields = ('title',)
    list_per_page = 20

    def get_extra_class_names_for_field_col(self, obj, field_name):
        if field_name == 'title_formatted':
            return ['title']
        return []

    # Mise en forme des champs
    # ------------------------

    def title_formatted(self, obj):
        return format_html('<h2>{}</h2>', obj.title)

    title_formatted.short_description = "Titre"
    title_formatted.admin_order_field = 'title'

    def tags_list(self, obj):
        return format_html_join(
            ' ',
            '<span class="status-tag primary">{}</span>',
            ([t.name] for t in obj.tags.all()),
        )

    tags_list.short_description = "Étiquettes"


class PlaceModelAdmin(ModelAdmin):
    model = Place
    menu_label = "Lieux"
    menu_icon = 'site'


class EventsModelAdminGroup(ModelAdminGroup):
    menu_label = "Évènements"
    menu_icon = 'date'
    items = (EventModelAdmin, PlaceModelAdmin)


modeladmin_register(EventsModelAdminGroup)
